BlockBuilder

Struct BlockBuilder 

pub struct BlockBuilder<'a, Block: BlockT, C: ProvideRuntimeApi<Block> + 'a> { /* private fields */ }
Utility for building new (valid) blocks from a stream of extrinsics.

Implementations

Source

impl<'a, Block, C> BlockBuilder<'a, Block, C>
where Block: BlockT, C: CallApiAt<Block> + ProvideRuntimeApi<Block> + 'a, C::Api: BlockBuilderApi<Block>,

pub fn extrinsic_inclusion_mode(&self) -> ExtrinsicInclusionMode

The extrinsic inclusion mode of the runtime for this block.

pub fn push(&mut self, xt: <Block as BlockT>::Extrinsic) -> Result<(), Error>

Push onto the block’s list of extrinsics.

This will ensure the extrinsic can be validly executed (by executing it).

pub fn build(self) -> Result<BuiltBlock<Block>, Error>

Consume the builder to build a valid Block containing all pushed extrinsics.

Returns the build Block, the changes to the storage and an optional StorageProof supplied by self.api, combined as BuiltBlock. The storage proof will be Some(_) when proof recording was enabled.

pub fn create_inherents( &mut self, inherent_data: InherentData, ) -> Result<Vec<Block::Extrinsic>, Error>

Create the inherents for the block.

Returns the inherents created by the runtime or an error if something failed.

pub fn estimate_block_size(&self) -> usize

Estimate the size of the block in the current state.

If include_proof is true, the estimated size of the storage proof will be added to the estimation.

pub fn proof_recorder(&self) -> Option<ProofRecorder<Block>>

Returns the ProofRecorder set for the block building.