pub struct BuiltBlock<Block: BlockT> {
pub block: Block,
pub storage_changes: StorageChanges<Block>,
}Expand description
A block that was build by BlockBuilder plus some additional data.
This additional data includes the storage_changes, these changes can be applied to the
backend to get the state of the block.
Fields
block: BlockThe actual block that was build.
storage_changes: StorageChanges<Block>The changes that need to be applied to the backend to get the state of the build block.
Implementations
Sourceimpl<Block: BlockT> BuiltBlock<Block>
impl<Block: BlockT> BuiltBlock<Block>
Sourcepub fn into_inner(self) -> (Block, StorageChanges<Block>)
pub fn into_inner(self) -> (Block, StorageChanges<Block>)
Convert into the inner values.