Validation

Enum Validation 

pub enum Validation {
    Success {
        is_new_best: bool,
    },
    Failure {
        disconnect: bool,
    },
}
Result of BlockAnnounceValidator::validate.

Variants



Success

Valid block announcement.

Fields

is_new_best: bool

Is this the new best block of the node?



Failure

Invalid block announcement.

Fields

disconnect: bool

Should we disconnect from this peer?

This should be used if the peer for example send junk to spam us.