StateDb

Struct StateDb 

pub struct StateDb<BlockHash: Hash, Key: Hash, D: MetaDb> { /* private fields */ }
State DB maintenance. See module description. Can be shared across threads.

Implementations

Source

impl<BlockHash: Hash, Key: Hash, D: MetaDb> StateDb<BlockHash, Key, D>

pub fn open( db: D, requested_mode: Option<PruningMode>, ref_counting: bool, should_init: bool, ) -> Result<(CommitSet<Key>, StateDb<BlockHash, Key, D>), Error<D::Error>>

Create an instance of StateDb.

pub fn pruning_mode(&self) -> PruningMode

pub fn insert_block( &self, hash: &BlockHash, number: u64, parent_hash: &BlockHash, changeset: ChangeSet<Key>, ) -> Result<CommitSet<Key>, Error<D::Error>>

Add a new non-canonical block.

pub fn canonicalize_block( &self, hash: &BlockHash, ) -> Result<CommitSet<Key>, Error<D::Error>>

Finalize a previously inserted block.

pub fn pin<F>( &self, hash: &BlockHash, number: u64, hint: F, ) -> Result<(), PinError>
where F: Fn() -> bool,

Prevents pruning of specified block and its descendants. hint used for further checking if the given block exists

pub fn unpin(&self, hash: &BlockHash)

Allows pruning of specified block.

pub fn sync(&self)

Confirm that all changes made to commit sets are on disk. Allows for temporarily pinned blocks to be released.

pub fn get<DB: NodeDb, Q>( &self, key: &Q, db: &DB, ) -> Result<Option<DBValue>, Error<DB::Error>>
where Q: AsRef<DB::Key> + Hash + Eq + ?Sized, Key: Borrow<Q>,

Get a value from non-canonical/pruning overlay or the backing DB.

pub fn revert_one(&self) -> Option<CommitSet<Key>>

Revert all non-canonical blocks with the best block number. Returns a database commit or None if not possible. For archive an empty commit set is returned.

pub fn remove(&self, hash: &BlockHash) -> Option<CommitSet<Key>>

Remove specified non-canonical block. Returns a database commit or None if not possible.

pub fn last_canonicalized(&self) -> LastCanonicalized

Returns last canonicalized block.

pub fn is_pruned(&self, hash: &BlockHash, number: u64) -> IsPruned

Check if block is pruned away.

pub fn reset(&self, db: D) -> Result<(), Error<D::Error>>

Reset in-memory changes to the last disk-backed state.