pub struct ProfilingLayer { /* private fields */ }Expand description
Responsible for assigning ids to new spans, which are not re-used.
Implementations
Sourceimpl ProfilingLayer
impl ProfilingLayer
Sourcepub fn new(receiver: TracingReceiver, targets: &str) -> Self
pub fn new(receiver: TracingReceiver, targets: &str) -> Self
Takes a TracingReceiver and a comma separated list of targets,
either with a level: “pallet=trace,frame=debug”
or without: “pallet,frame” in which case the level defaults to trace.
wasm_tracing indicates whether to enable wasm traces
Sourcepub fn new_with_handler(
trace_handler: Box<dyn TraceHandler>,
targets: &str,
) -> Self
pub fn new_with_handler( trace_handler: Box<dyn TraceHandler>, targets: &str, ) -> Self
Allows use of a custom TraceHandler to create a new instance of ProfilingSubscriber.
Takes a comma separated list of targets,
either with a level, eg: “pallet=trace”
or without: “pallet” in which case the level defaults to trace.
wasm_tracing indicates whether to enable wasm traces
Sourcepub fn add_handler(&mut self, trace_handler: Box<dyn TraceHandler>)
pub fn add_handler(&mut self, trace_handler: Box<dyn TraceHandler>)
Attach additional handlers to allow handling of custom events/spans.