pub struct Hub<M, R> { /* private fields */ }Expand description
A subscription hub.
Does the subscription and dispatch.
The exact subscription and routing behaviour is to be implemented by the Registry (of type R).
The Hub under the hood uses the channel defined in crate::utils::mpsc module.
Implementations
Sourceimpl<M, R> Hub<M, R>where
R: Unsubscribe,
impl<M, R> Hub<M, R>where
R: Unsubscribe,
Sourcepub fn map_registry_for_tests<MapF, Ret>(&self, map: MapF) -> Ret
pub fn map_registry_for_tests<MapF, Ret>(&self, map: MapF) -> Ret
Provide access to the registry (for test purposes).
Sourceimpl<M, R> Hub<M, R>
impl<M, R> Hub<M, R>
Sourcepub fn new(tracing_key: &'static str) -> Selfwhere
R: Default,
pub fn new(tracing_key: &'static str) -> Selfwhere
R: Default,
Create a new instance of Hub (with default value for the Registry).
Sourcepub fn new_with_registry(tracing_key: &'static str, registry: R) -> Self
pub fn new_with_registry(tracing_key: &'static str, registry: R) -> Self
Create a new instance of Hub over the initialized Registry.