pub struct StateDb<BlockHash: Hash, Key: Hash, D: MetaDb> { /* private fields */ }Expand description
State DB maintenance. See module description. Can be shared across threads.
Implementations
Sourceimpl<BlockHash: Hash, Key: Hash, D: MetaDb> StateDb<BlockHash, Key, D>
impl<BlockHash: Hash, Key: Hash, D: MetaDb> StateDb<BlockHash, Key, D>
Sourcepub fn open(
db: D,
requested_mode: Option<PruningMode>,
ref_counting: bool,
should_init: bool,
) -> Result<(CommitSet<Key>, StateDb<BlockHash, Key, D>), Error<D::Error>>
pub fn open( db: D, requested_mode: Option<PruningMode>, ref_counting: bool, should_init: bool, ) -> Result<(CommitSet<Key>, StateDb<BlockHash, Key, D>), Error<D::Error>>
Create an instance of StateDb.
pub fn pruning_mode(&self) -> PruningMode
Sourcepub fn insert_block(
&self,
hash: &BlockHash,
number: u64,
parent_hash: &BlockHash,
changeset: ChangeSet<Key>,
) -> Result<CommitSet<Key>, Error<D::Error>>
pub fn insert_block( &self, hash: &BlockHash, number: u64, parent_hash: &BlockHash, changeset: ChangeSet<Key>, ) -> Result<CommitSet<Key>, Error<D::Error>>
Add a new non-canonical block.
Sourcepub fn canonicalize_block(
&self,
hash: &BlockHash,
) -> Result<CommitSet<Key>, Error<D::Error>>
pub fn canonicalize_block( &self, hash: &BlockHash, ) -> Result<CommitSet<Key>, Error<D::Error>>
Finalize a previously inserted block.
Sourcepub fn pin<F>(
&self,
hash: &BlockHash,
number: u64,
hint: F,
) -> Result<(), PinError>
pub fn pin<F>( &self, hash: &BlockHash, number: u64, hint: F, ) -> Result<(), PinError>
Prevents pruning of specified block and its descendants.
hint used for further checking if the given block exists
Sourcepub fn unpin(&self, hash: &BlockHash)
pub fn unpin(&self, hash: &BlockHash)
Allows pruning of specified block.
Sourcepub fn sync(&self)
pub fn sync(&self)
Confirm that all changes made to commit sets are on disk. Allows for temporarily pinned blocks to be released.
Sourcepub fn get<DB: NodeDb, Q>(
&self,
key: &Q,
db: &DB,
) -> Result<Option<DBValue>, Error<DB::Error>>
pub fn get<DB: NodeDb, Q>( &self, key: &Q, db: &DB, ) -> Result<Option<DBValue>, Error<DB::Error>>
Get a value from non-canonical/pruning overlay or the backing DB.
Sourcepub fn revert_one(&self) -> Option<CommitSet<Key>>
pub fn revert_one(&self) -> Option<CommitSet<Key>>
Revert all non-canonical blocks with the best block number.
Returns a database commit or None if not possible.
For archive an empty commit set is returned.
Sourcepub fn remove(&self, hash: &BlockHash) -> Option<CommitSet<Key>>
pub fn remove(&self, hash: &BlockHash) -> Option<CommitSet<Key>>
Remove specified non-canonical block.
Returns a database commit or None if not possible.
Sourcepub fn last_canonicalized(&self) -> LastCanonicalized
pub fn last_canonicalized(&self) -> LastCanonicalized
Returns last canonicalized block.
Sourcepub fn is_pruned(&self, hash: &BlockHash, number: u64) -> IsPruned
pub fn is_pruned(&self, hash: &BlockHash, number: u64) -> IsPruned
Check if block is pruned away.